@@ -4,12 +4,16 @@ import googleanalytics as ga
 from common import authenticated, cli
 
 @cli.command()
-@click.option('-s', '--show', is_flag=True)
+@click.option('-s', '--show')
 @authenticated
 def authorize(identity, accounts, show=False):
     credentials = ga.auth.identity(identity)
 
-    if show: 
-        print json.dumps(credentials.serialize(), indent=4)
+    if show:
+        if show == 'pairs':
+            for key, value in credentials.items():
+                print key, '=', value
+        else:
+            print json.dumps(credentials.serialize(), indent=4)
 
     return credentials
